@@ -2,23 +2,25 @@
 
 from abc import ABC, abstractmethod
 import inspect
-
+import logging
 
 class TestCase(ABC):
     """Base for all test cases"""
 
     def __init__(self):
         self.results = {}
+        self.logger = logging.getLogger('test_case')
 
     @abstractmethod
     def test(self, instruments, dut):
-        """Contains the test sequence"""
+        """Defines the test case."""
 
     def new_result(self, name, result):
+        """Adds new result to result array"""
         self.results[name] = result
 
     def result_handler(self, limits):
-        """Checks if test is pass or fail. Can be overridden if needed"""
+        """Checks if test is pass or fail. Can be overridden if needed."""
 
         tmp_result = {}
 
